@@ -10,7 +10,7 @@ from maggma.api.models import Response as ResponseModel
 from maggma.api.query_operator import PaginationQuery, QueryOperator, SparseFieldsQuery
 from maggma.api.resource import Resource, HintScheme, HeaderProcessor
 from maggma.api.resource.utils import attach_query_ops
-from maggma.api.utils import STORE_PARAMS, merge_queries, object_id_serilaization_helper
+from maggma.api.utils import STORE_PARAMS, merge_queries, serialization_helper
 from maggma.core import Store
 from maggma.stores.mongolike import MongoStore
 
@@ -79,10 +79,7 @@ class ReadOnlyResource(Resource):
             if query_operators is not None
             else [
                 PaginationQuery(),
-                SparseFieldsQuery(
-                    model,
-                    default_fields=[self.store.key, self.store.last_updated_field],
-                ),
+                SparseFieldsQuery(model, default_fields=[self.store.key, self.store.last_updated_field],),
             ]
         )
 
@@ -105,9 +102,7 @@ class ReadOnlyResource(Resource):
         model_name = self.model.__name__
 
         if self.key_fields is None:
-            field_input = SparseFieldsQuery(
-                self.model, [self.store.key, self.store.last_updated_field]
-            ).query
+            field_input = SparseFieldsQuery(self.model, [self.store.key, self.store.last_updated_field]).query
         else:
 
             def field_input():
@@ -116,10 +111,8 @@ class ReadOnlyResource(Resource):
         async def get_by_key(
             request: Request,
             response: Response,
-            key: str = Path(
-                ..., alias=key_name, title=f"The {key_name} of the {model_name} to get",
-            ),
-            fields: STORE_PARAMS = Depends(field_input),
+            key: str = Path(..., alias=key_name, title=f"The {key_name} of the {model_name} to get",),
+            _fields: STORE_PARAMS = Depends(field_input),
         ):
             f"""
             Get's a document by the primary key in the store
@@ -132,16 +125,11 @@ class ReadOnlyResource(Resource):
             """
             self.store.connect()
 
-            item = [
-                self.store.query_one(
-                    criteria={self.store.key: key}, properties=fields["properties"],
-                )
-            ]
+            item = [self.store.query_one(criteria={self.store.key: key}, properties=_fields["properties"],)]
 
             if item == [None]:
                 raise HTTPException(
-                    status_code=404,
-                    detail=f"Item with {self.store.key} = {key} not found",
+                    status_code=404, detail=f"Item with {self.store.key} = {key} not found",
                 )
 
             for operator in self.query_operators:
@@ -151,7 +139,7 @@ class ReadOnlyResource(Resource):
 
             if self.disable_validation:
                 response = Response(  # type: ignore
-                    orjson.dumps(response, default=object_id_serilaization_helper)
+                    orjson.dumps(response, default=serialization_helper)
                 )
 
             if self.header_processor is not None:
@@ -178,21 +166,25 @@ class ReadOnlyResource(Resource):
             response: Response = queries.pop("temp_response")  # type: ignore
 
             query_params = [
-                entry
-                for _, i in enumerate(self.query_operators)
-                for entry in signature(i.query).parameters
+                entry for _, i in enumerate(self.query_operators) for entry in signature(i.query).parameters
             ]
 
-            overlap = [
-                key for key in request.query_params.keys() if key not in query_params
-            ]
+            overlap = [key for key in request.query_params.keys() if key not in query_params]
             if any(overlap):
-                raise HTTPException(
-                    status_code=400,
-                    detail="Request contains query parameters which cannot be used: {}".format(
-                        ", ".join(overlap)
-                    ),
-                )
+                if "limit" in overlap or "skip" in overlap:
+                    raise HTTPException(
+                        status_code=400,
+                        detail="'limit' and 'skip' parameters have been renamed. "
+                        "Please update your API client to the newest version.",
+                    )
+
+                else:
+                    raise HTTPException(
+                        status_code=400,
+                        detail="Request contains query parameters which cannot be used: {}".format(
+                            ", ".join(overlap)
+                        ),
+                    )
 
             query: Dict[Any, Any] = merge_queries(list(queries.values()))  # type: ignore
 
@@ -202,13 +194,7 @@ class ReadOnlyResource(Resource):
 
             self.store.connect()
 
-            count = self.store.count(
-                **{
-                    field: query[field]
-                    for field in query
-                    if field in ["criteria", "hint"]
-                }
-            )
+            count = self.store.count(**{field: query[field] for field in query if field in ["criteria", "hint"]})
 
             data = list(self.store.query(**query))
             operator_meta = {}
@@ -223,7 +209,7 @@ class ReadOnlyResource(Resource):
 
             if self.disable_validation:
                 response = Response(  # type: ignore
-                    orjson.dumps(response, default=object_id_serilaization_helper)
+                    orjson.dumps(response, default=serialization_helper)
                 )
 
             if self.header_processor is not None:
